EVENT_CODES = {
    0: 'Transform',
    1: 'Input',
    2: 'Interactor',
    3: 'Interactable',
    4: 'EyeBegin',
    5: 'EyeEnd',
    6: 'RayBegin',
    7: 'RayEnd',
    8: 'TriggerBegin',
    9: 'TriggerEnd',
    10: 'Action',
    11: 'HeartRate',
    12: 'ExperimentalControl'
}